@@ -1,5 +1,4 @@
 from django.conf import settings
-from django.db import connections
 from django.utils.module_loading import import_string
 
 
@@ -26,7 +25,5 @@ MIDDLEWARES = settings.MIDDLEWARE
 #  It will prevent error in database if User is not in the same database (because of ForeignKey)
 LOGGING_DATABASE = getattr(settings, 'LOGGING_DATABASE', 'default')
 
-USE_POSTGRES = connections[LOGGING_DATABASE].client.executable_name == 'psql'
-
 JSON_ENCODER_PATH = getattr(settings, 'LOGGING_JSON_ENCODER', 'models_logging.utils.ExtendedEncoder')
 JSON_ENCODER = import_string(JSON_ENCODER_PATH)
